@@ -1,24 +1,14 @@
+# Settings for netauth.node42.org
+
 from settings.core import *
 
-# PROJECT SETTINGS
-# -----------------
-INSTALLED_APPS += (
 
-    # Community apps
-    'south',
+# MAIN APPLICATION
+INSTALLED_APPS += ('main', )
 
-    # Base project app
-    'main',
-
-)
-CACHE_PREFIX = "PROD"
-
-
-# NETAUTH
-# --------
-INSTALLED_APPS += ( 'netauth',)
-MIDDLEWARE_CLASSES += ( 'netauth.middleware.RedirectMiddleware', )
-AUTHENTICATION_BACKENDS = ( 'netauth.auth.NetBackend', )
+# NETAUTH_SETTINGS
+AUTHENTICATION_BACKENDS = ( 'django.contrib.auth.backends.ModelBackend', 'netauth.auth.NetBackend', )
+INSTALLED_APPS += ('netauth', )
 
 YANDEX_APPLICATION_ID = "51a38f59a8cf4e96b7635d33a5b37bfe"
 
