@@ -1,11 +1,15 @@
 import logging
 
 
-__version__ = VERSION = '0.1.4'
+VERSION_INFO = (0, 1, 5)
+
+__version__ = VERSION = '.'.join(map(str, VERSION_INFO ))
 __project__ = PROJECT = 'django-netauth'
+__author__ = AUTHOR = "Kirill Klenov <horneds@gmail.com>"
+__license__ = LICENSE = "GNU LGPL"
 
 
-LOG = logging.getLogger( __name__ )
+NETAUTH_LOG = logging.getLogger( __name__ )
 
 
 class RedirectException(Exception):
